@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2007 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,15 +14,15 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides the default implementation for flat review for Orca."""
 
-__id__        = "$Id: flat_review.py 3598 2008-02-19 00:48:06Z joanied $"
-__version__   = "$Revision: 3598 $"
-__date__      = "$Date: 2008-02-18 19:48:06 -0500 (Mon, 18 Feb 2008) $"
-__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
+__id__        = "$Id: flat_review.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import re
@@ -531,10 +531,19 @@ class Line:
                 # The 'isinstance(zone, TextZone)' test is a sanity check
                 # to handle problems with Java text. See Bug 435553.
                 if isinstance(zone, TextZone) and \
-                   ((zone.accessible.getRole() == pyatspi.ROLE_TEXT) \
-                    or (zone.accessible.getRole() == \
-                                                pyatspi.ROLE_PASSWORD_TEXT) \
-                    or (zone.accessible.getRole() == pyatspi.ROLE_TERMINAL)):
+                   ((zone.accessible.getRole() in \
+                         (pyatspi.ROLE_TEXT,  
+                          pyatspi.ROLE_PASSWORD_TEXT,
+                          pyatspi.ROLE_TERMINAL)) or \
+                    # [[[TODO: Eitan - HACK: 
+                    # This is just to get FF3 cursor key routing support.
+                    # We really should not be determining all this stuff here,
+                    # it should be in the scripts. 
+                    # Same applies to roles above.]]]
+                    (zone.accessible.getRole() in \
+                         (pyatspi.ROLE_PARAGRAPH,
+                          pyatspi.ROLE_HEADING,
+                          pyatspi.ROLE_LINK))):
                     region = braille.ReviewText(zone.accessible,
                                                 zone.string,
                                                 zone.startOffset,
@@ -1052,7 +1061,11 @@ class Context:
             if action:
                 hasToggle = False
                 for i in range(0, action.nActions):
-                    if action.getName(i) == "toggle":
+                    # Translators: this is the action name for
+                    # the 'toggle' action. It must be the same
+                    # string used in the *.po file for gail.
+                    #
+                    if action.getName(i) in ["toggle", _("toggle")]:
                         hasToggle = True
                         break
                 if hasToggle:
