@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2007 Sun Microsystems Inc.
+# Copyright 2004-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,15 +14,15 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """The main module for the Orca screen reader."""
 
-__id__        = "$Id: orca.py 3561 2008-02-11 18:11:45Z wwalker $"
-__version__   = "$Revision: 3561 $"
-__date__      = "$Date: 2008-02-11 13:11:45 -0500 (Mon, 11 Feb 2008) $"
-__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
+__id__        = "$Id: orca.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 # We're going to force the name of the app to "orca" so pygtk
@@ -44,6 +44,12 @@ try:
 except:
     pass
 
+try:
+    # If we don't have an active desktop, we will get a RuntimeError.
+    import mouse_review
+except RuntimeError:
+    pass
+
 import getopt
 import gnome
 import os
@@ -54,6 +60,7 @@ import unicodedata
 import pyatspi
 import braille
 import debug
+import dbusserver
 import httpserver
 import keynames
 import keybindings
@@ -141,6 +148,17 @@ def _switchToNextPresentationManager(script=None, inputEvent=None):
     _switchToPresentationManager(_currentPresentationManager + 1)
     return True
 
+def getScriptForApp(app):
+    """Get the script for the given application object from the current
+    presentation manager.
+
+    Arguments:
+    - app: An application accessible.
+
+    Returns a Script instance.
+    """
+    return _PRESENTATION_MANAGERS[_currentPresentationManager].getScript(app)
+
 ########################################################################
 #                                                                      #
 # METHODS TO HANDLE APPLICATION LIST AND FOCUSED OBJECTS               #
@@ -297,6 +315,27 @@ def cycleDebugLevel(script=None, inputEvent=None):
 
     return True
 
+def exitLearnMode(self, inputEvent=None):
+    """Turns learn mode off.
+
+    Returns True to indicate the input event has been consumed.
+    """
+
+    # Translators: Orca has a "Learn Mode" that will allow
+    # the user to type any key on the keyboard and hear what
+    # the effects of that key would be.  The effects might
+    # be what Orca would do if it had a handler for the
+    # particular key combination, or they might just be to
+    # echo the name of the key if Orca doesn't have a handler.
+    # Exiting learn mode puts the user back in normal operating
+    # mode.
+    #
+    message = _("Exiting learn mode.")
+    speech.speak(message)
+    braille.displayMessage(message)
+    settings.learnModeEnabled = False
+    return True
+
 ########################################################################
 #                                                                      #
 # METHODS FOR PRE-PROCESSING AND MASSAGING KEYBOARD EVENTS.            #
@@ -739,6 +778,10 @@ def _processKeyboardEvent(event):
                         event_string = keyboardEvent.event_string
                         event_string = keynames.getKeyName(event_string)
                         speech.speak(event_string)
+                elif (event.type == pyatspi.KEY_RELEASED_EVENT) and \
+                     (keyboardEvent.event_string == "Escape"):
+                    exitLearnMode(keyboardEvent)
+
                 consumed = True
     except:
         debug.printException(debug.LEVEL_SEVERE)
@@ -817,6 +860,7 @@ def loadUserSettings(script=None, inputEvent=None):
 
     # Shutdown the output drivers and give them a chance to die.
     #
+    dbusserver.shutdown()
     httpserver.shutdown()
     speech.shutdown()
     braille.shutdown()
@@ -890,6 +934,14 @@ def loadUserSettings(script=None, inputEvent=None):
         debug.println(debug.LEVEL_CONFIGURATION,
                       "Magnification module has NOT been initialized.")
 
+
+    # I'm not sure where else this should go. But it doesn't really look
+    # right here.
+    try:
+        mouse_review.mouse_reviewer.toggle(on=settings.enableMouseReview)
+    except NameError:
+        pass
+
     # We don't want the Caps_Lock modifier to act as a locking
     # modifier if it used as the Orca modifier key.  In addition, if
     # the KP_Insert key is used as the Orca modifier key, we want to
@@ -920,6 +972,7 @@ def loadUserSettings(script=None, inputEvent=None):
 
     showMainWindowGUI()
 
+    dbusserver.init()
     httpserver.init()
 
     return True
@@ -993,7 +1046,7 @@ def _showPreferencesConsole(script=None, inputEvent=None):
                             globals(),
                             locals(),
                             [''])
-        module.showPreferencesUI()
+        module.showPreferencesUI(_commandLineSettings)
     except:
         debug.printException(debug.LEVEL_SEVERE)
 
@@ -1341,6 +1394,14 @@ def usage():
             "will automatically launch the preferences set up unless\n" \
             "the -n or --no-setup option is used.")
 
+    # Translators: this is more text being sent to a terminal and we want to 
+    # keep the text lines within terminal boundaries.
+    #
+    print
+    print _("WARNING: suspending Orca, e.g. by pressing Control-Z, from\n" \
+            "an AT-SPI enabled shell (such as gnome-terminal), can also\n" \
+            "suspend the desktop until Orca is killed.")
+
     print
     print _("Report bugs to orca-list@gnome.org.")
 
