@@ -14,16 +14,16 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Manages the settings for Orca.  This will defer to user settings first, but
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 3819 2008-04-07 19:20:05Z wwalker $"
-__version__   = "$Revision: 3819 $"
-__date__      = "$Date: 2008-04-07 15:20:05 -0400 (Mon, 07 Apr 2008) $"
+__id__        = "$Id: settings.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -105,6 +105,7 @@ userCustomizableSettings = [
     "brailleVerbosityLevel",
     "brailleRolenameStyle",
     "brailleSelectorIndicator",
+    "brailleLinkIndicator",
     "enableBrailleMonitor",
     "enableMagnifier",
     "enableMagLiveUpdating",
@@ -229,6 +230,16 @@ BRAILLE_SEL_8    = 0x80 # 10000000
 BRAILLE_SEL_BOTH = 0xc0 # 11000000
 brailleSelectorIndicator = BRAILLE_SEL_BOTH
 
+# Braille Link Indicator (see brailleLinkIndicator).
+# The values represent the character to be used in the attrOr
+# field of brlAPI's writeStruct.
+#
+BRAILLE_LINK_NONE = 0x00 # 00000000
+BRAILLE_LINK_7    = 0x40 # 01000000
+BRAILLE_LINK_8    = 0x80 # 10000000
+BRAILLE_LINK_BOTH = 0xc0 # 11000000
+brailleLinkIndicator = BRAILLE_LINK_BOTH
+
 # Speech punctuation levels (see verbalizePunctuationStyle).
 #
 PUNCTUATION_STYLE_NONE = 3
@@ -767,7 +778,8 @@ settingsPackages          = ["app-settings"]
 # REMEMBER: to make something a package, the directory has to
 # have a __init__.py file in it.
 #
-scriptPackages          = ["orca-scripts", "scripts"]
+scriptPackages          = ["orca-scripts", "scripts", 
+                           "scripts.apps", "scripts.toolkits"]
 
 # A list that helps us map application names to script module
 # names.  The key is the name of an application, and the value is
@@ -825,22 +837,22 @@ def getScriptModuleName(app):
 # I wish the AT-SPI spec'd this out as machine readable (unlocalized)
 # names, but it's what we're stuck with (unfortunately).
 #
-setScriptMapping(re.compile(_('[\S\s]*StarOffice[\s\S]*')), "StarOffice")
+setScriptMapping(re.compile(_('[\S\s]*StarOffice[\s\S]*')), "soffice")
 
 # Translators: see the regular expression note above.  This is for
 # OpenOffice and StarOffice.
 #
-setScriptMapping(re.compile(_('soffice.bin')), "StarOffice")
+setScriptMapping(re.compile(_('soffice.bin')), "soffice")
 
 # Translators: see the regular expression note above.  This is for
 # OpenOffice and StarOffice.
 #
-setScriptMapping(re.compile(_('soffice')), "StarOffice")
+setScriptMapping(re.compile(_('soffice')), "soffice")
 
 # Translators: see the regular expression note above.  This is for the
 # Evolution mail application.
 #
-setScriptMapping(re.compile(_('[Ee]volution')), "Evolution")
+setScriptMapping(re.compile(_('[Ee]volution')), "evolution")
 
 # Translators: see the regular expression note above.  This is for the
 # help application (yelp).
@@ -881,9 +893,9 @@ setScriptMapping(re.compile(_('bug-buddy')), "gnome_segv2")
 setScriptMapping(re.compile(_('vte')), "gnome-terminal")
 
 # Translators: see the regular expression note above.  This is for
-# supporting pidgin, which is the new name for gaim.
+# supporting gaim, which has recently be renamed to pidgin.
 #
-setScriptMapping(re.compile(_('pidgin')), "gaim")
+setScriptMapping(re.compile(_('gaim')), "pidgin")
 
 # Show deprecated messeges in debug output.
 # Set this to True to help find potential pyatspi porting problems
